==> org.eclipse.ui.workbench.source_3.107.0.v20150825-2206.jar: org/eclipse/ui/internal/dialogs/cpd/ActionSetSelectionChangedListener.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2014 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.ui.internal.dialogs.cpd;

import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.ui.internal.dialogs.cpd.CustomizePerspectiveDialog.ActionSet;

/**
 * A Listener for a list of command groups, that updates the viewer and filter
 * who are dependent on the action set selection.
 *
 * @since 3.5
 */
final class ActionSetSelectionChangedListener implements ISelectionChangedListener {
	private final TreeViewer filterViewer;
	private final ActionSetFilter filter;

	public ActionSetSelectionChangedListener(TreeViewer viewer, ActionSetFilter menuStructureFilterByActionSet) {
		this.filterViewer = viewer;
		this.filter = menuStructureFilterByActionSet;
	}

	@Override
	public void selectionChanged(SelectionChangedEvent event) {
		Object element = ((IStructuredSelection) event.getSelection()).getFirstElement();
		filter.setActionSet((ActionSet) element);
		filterViewer.refresh();
		filterViewer.expandAll();
	}
}

==> org.eclipse.ui.workbench.source_3.113.0.v20190219-1432.jar: org/eclipse/ui/internal/dialogs/cpd/ActionSetSelectionChangedListener.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2018 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.ui.internal.dialogs.cpd;

import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.ui.internal.dialogs.cpd.CustomizePerspectiveDialog.ActionSet;

/**
 * A Listener for a list of command groups, that updates the viewer and filter
 * who are dependent on the action set selection.
 *
 * @since 3.5
 */
final class ActionSetSelectionChangedListener implements ISelectionChangedListener {
	private final TreeViewer filterViewer;
	private final ActionSetFilter filter;

	public ActionSetSelectionChangedListener(TreeViewer viewer, ActionSetFilter menuStructureFilterByActionSet) {
		this.filterViewer = viewer;
		this.filter = menuStructureFilterByActionSet;
	}

	@Override
	public void selectionChanged(SelectionChangedEvent event) {
		Object element = event.getStructuredSelection().getFirstElement();
		filter.setActionSet((ActionSet) element);
		filterViewer.refresh();
		filterViewer.expandAll();
	}
}
